@@ -14,7 +14,10 @@ def run_as(user):
         return inner
     return decorator
 
-def upload_hosting_template(name, to):
+def upload_hosting_template(name, to=None):
+    base_dir = "%s/hosting/" % env.conf['SRC_DIR']
+    if to is None:
+        to = base_dir + 'generated/%s' % name
     upload_template('./hosting/templates/'+name, to, env.conf, True)
 
 def update_env():
